from setuptools import setup, find_packages

setup(
    name="trng",  # Package name
    version="0.1.0",  # Initial version
    author="Joon Won Song",
    author_email="meric.song20@imperial.ac.uk",
    description="A simple library for generating AES keys using IoT based TRNG.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/songmeric/trng",  # Replace with your GitHub repo (if available)
    packages=find_packages(),
    install_requires=[
        "paho-mqtt",
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",  # Minimum Python version
)
